@@ -1,4 +1,5 @@
 # coding: utf8
+from atlassian import utils
 from .rest_client import AtlassianRestAPI
 from requests import HTTPError
 import logging
@@ -446,9 +447,11 @@ class Confluence(AtlassianRestAPI):
         :return: True if the same
         """
         confluence_content = (((self.get_page_by_id(page_id, expand='body.storage') or {})
-                              .get('body') or {})
+                               .get('body') or {})
                               .get('storage') or {}).get('value')
-        confluence_content = confluence_content.replace('&oacute;', u'ó')
+        if confluence_content:
+            # @todo move into utils
+            confluence_content = utils.symbol_normalizer(confluence_content)
 
         log.debug('Old Content: """{body}"""'.format(body=confluence_content))
         log.debug('New Content: """{body}"""'.format(body=body))
@@ -890,7 +893,6 @@ class Confluence(AtlassianRestAPI):
             params['limit'] = limit
         return self.get('rest/api/longtask', params=params)
 
-
     def get_pdf_download_url_for_confluence_cloud(self, url):
         """
         Confluence cloud does not return the PDF document when the PDF
