@@ -7,6 +7,17 @@ log = logging.getLogger(__name__)
 
 
 class Jira(AtlassianRestAPI):
+    def server_info(self, do_health_check=False):
+        """
+        Returns general information about the current JIRA server.
+        :param do_health_check:
+        :return:
+        """
+        params = {'doHealthCheck': False}
+        if do_health_check:
+            params['doHealthCheck'] = do_health_check
+        return self.get('rest/api/2/serverInfo', params=params)
+
     def reindex_status(self):
         return self.get('rest/api/2/reindex')
 
@@ -841,6 +852,15 @@ class Jira(AtlassianRestAPI):
         transition_id = self.get_transition_id_to_status_name(issue_key, status_name)
         return self.post(url, data={'transition': {'id': transition_id}})
 
+    def set_issue_status_by_id(self, issue_key, transition_id):
+        """
+        Setting status by transition_id
+        :param issue_key: str
+        :param transition_id: int
+        """
+        url = 'rest/api/2/issue/{issue_key}/transitions'.format(issue_key=issue_key)
+        return self.post(url, data={'transition': {'id': transition_id}})
+
     def get_issue_status(self, issue_key):
         url = 'rest/api/2/issue/{issue_key}?fields=status'.format(issue_key=issue_key)
         return (self.get(url) or {}).get('fields').get('status').get('name')
@@ -1028,6 +1048,15 @@ class Jira(AtlassianRestAPI):
         url = 'rest/plugins/1.0/?token={upm_token}'.format(upm_token=upm_token)
         return self.post(url, files=files, headers=headers)
 
+    def delete_plugin(self, plugin_key):
+        """
+        Delete plugin
+        :param plugin_key:
+        :return:
+        """
+        url = 'rest/plugins/1.0/{}-key'.format(plugin_key)
+        return self.delete(url)
+
     def check_plugin_manager_status(self):
         headers = {
             'X-Atlassian-Token': 'nocheck',
